@@ -44,22 +44,24 @@ if (length(attr(data, 'syntax')) >= 2) {
     eval(parse(text=attr(data, 'syntax')[[1]]))
     eval(parse(text=paste0('result2 = ', attr(data, 'syntax')[[2]])))
     names(result2)
-    # → "main"      "assump"    "contrasts" "postHoc"   "emm"
+    # -> "main"      "assump"    "contrasts" "postHoc"   "emm"
     # (the names of the five output tables)
 }
 
 ## ---- echo=TRUE---------------------------------------------------------------
 library(jmvReadWrite)
 
-# use the data set "ToothGrowth" and, if it exists, write it as jamovi-file using write_omv()
+# use the data set "ToothGrowth" and, if it exists, write it as jamovi-file
+# using write_omv()
 data("ToothGrowth");
-wrtDta = write_omv(ToothGrowth, "Trial.omv");
+# "retDbg" has to be set in order to return debug information to wrtDta
+wrtDta = write_omv(ToothGrowth, "Trial.omv", retDbg = TRUE);
 names(wrtDta);
-# → "mtaDta" "xtdDta" "dtaFrm"
-# returns a list with the metadata (mtaDta, e.g., column and data type),
-# the extended data (xtdDta, e.g., variable lables), and the data frame (dtaFrm)
-# the purpose of these variables is merely for checking (understanding the file format)
-# and debugging
+# -> "mtaDta" "xtdDta" "dtaFrm"
+# this debug information contains a list with the metadata ("mtaDta", e.g.,
+# column and data type), the extended data ("xtdDta", e.g., variable lables),
+# and the data frame (dtaFrm) for checking (understanding the file format) and
+# debugging
 
 # check whether the file was written to the disk, get the file information (size, etc.)
 # and delete the file afterwards
@@ -67,3 +69,18 @@ list.files(".", "Trial.omv");
 file.info("Trial.omv");
 unlink("Trial.omv");
 
+## ---- echo=TRUE---------------------------------------------------------------
+# reading and writing a file with the "sveAtt"-parameter permits you to keep
+# essential meta-data to ensure that the written file looks and works like the
+# original file (plus you modifications)
+fleOMV = system.file("extdata", "ToothGrowth.omv", package = "jmvReadWrite");
+data = read_omv(fleNme = fleOMV, sveAtt = TRUE);
+# shows the names of the attributes for the whole data set (e.g., number of
+# rows and columns) and the names of the attributes of the first column
+names(attributes(data));
+names(attributes(data[[1]]));
+#
+# perhaps do some modifications to the file here and write it back afterwards
+write_omv(data, 'Trial.omv');
+unlink("Trial.omv");
+
